@@ -367,6 +367,20 @@ See https://github.com/emacs-lsp/lsp-mode."
                                 (when lsp-auto-configure
                                   (lsp-diagnostics--enable))))
 
+(defun lsp-diagnostics--clear-after-edit (&rest _)
+  "Clear diagnostics for the current buffer after workspace edits.
+This prevents stale diagnostics from appearing at wrong line numbers
+when workspace edits shift line positions (see issue #3888)."
+  (when-let* ((file-path (buffer-file-name))
+              (workspaces (lsp-workspaces)))
+    (let ((path (lsp--fix-path-casing file-path)))
+      (dolist (workspace workspaces)
+        (-let [diagnostics (lsp--workspace-diagnostics workspace)]
+          (remhash path diagnostics))))
+    (run-hooks 'lsp-diagnostics-updated-hook)))
+
+(add-hook 'lsp-after-apply-edits-hook #'lsp-diagnostics--clear-after-edit)
+
 (lsp-consistency-check lsp-diagnostics)
 
 (provide 'lsp-diagnostics)
